/* Driver for Dazzle/SCM usbat2 Compact Flash reader
 * Header File
 *
 * Current development and maintenance by:
 *   (c) 2002 Thomas Kreiling (usbdev AT sm04.de)
 *
 * See usbat2_.c for more explanation
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2, or (at your option) any
 * later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef _USB_USBAT2CF_H
#define _USB_USBAT2CF_H

extern int usbat2_transport(Scsi_Cmnd *srb, struct us_data *us);
extern int init_usbat2(struct us_data *us);

#include <linux/hdreg.h>

#define USBAT_ATA		0x40

#define ATA_REG_DATA		0x10
#define ATA_REG_FEATURES	0x11
#define ATA_REG_ERROR		0x11
#define ATA_REG_SECCNT		0x12
#define ATA_REG_LBA_LO		0x13
#define ATA_REG_LBA_ME		0x14
#define ATA_REG_LBA_HI		0x15
#define ATA_REG_DEVICE		0x16
#define ATA_REG_STATUS		0x17
#define ATA_REG_CMD			0x17

#define ATA_CMD_DEVICE_RESET                    0x08
#define ATA_CMD_READ_SECTORS                    0x20
#define ATA_CMD_IDENTIFY_PACKET_DEVICE			0xa1
#define ATA_CMD_SET_MULTIPLE_MODE               0xc6
#define ATA_CMD_GET_MEDIA_STATUS                0xda
#define ATA_CMD_IDENTIFY_DEVICE                 0xec

#define ATA_LBA_MASK            0x0FFFFFFF

#define ATA_STATUS_DRDY         0x50            /* device ready */
#define ATA_STATUS_DRQ          0x08            /* data ready */

// usbat-02 specific commands
#define TYPE_WRITE	0x40
#define TYPE_READ	0xc0
#define EXEC_PACKED_COMMANDS	0x80
#define CSHTL_SET_FEATURE		0x81
#define USER_IO_ACC_REGISTER	0x82
#define ONE_COMMAND	0x8
#define TWO_COMMANDS	0x16
#define READ_ACCESS	0x1
#define WRITE_ACCESS	0x0
	// User I/O Register
#define EPAD		0x80	// Enable Pad
#define CDT			0x40	// card detect
#define UIO1		0x20
#define UIO0		0x10
#define EPP_ATA		0x8
#define UI1			0x4
#define UI0			0x2
#define INTR_ACK	0x1
	// User I/O Enable Register
#define DRVRST		0x80	// Periphical Device reset
#define ACKD		0x40
#define OE1			0x20	// 1: value of UIO1 is output, 0: input
#define OE0			0x10	// 1: value of UIO0 is output, 0: input
#define ADAPTER_RESET	0x1
	// CShtl_SetFeature, External Trigger Set Register
#define ETEN		0x80	// 1: Externel trigger enabled
#define U1			0x8
#define U0			0x4
#define ET1			0x2	
#define ET0			0x1		// bits of ET0+ET2 are set: Logic high, only bit of ET0: Logic low

static struct hd_driveid drive;

struct usbat2_info {
   unsigned long   sectors;     // total sector count
   unsigned long   ssize;       // sector size in bytes
   __u16 heads;
   __u16 sec_per_track;


   // the following aren't used yet
   unsigned char   sense_key;
   unsigned long   sense_asc;   // additional sense code
   unsigned long   sense_ascq;  // additional sense code qualifier
};

#endif
